@@ -19,7 +19,7 @@ use aliased 'Devel::Declare::Context::Simple', 'ContextSimple';
 
 use namespace::autoclean;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 has package => (
     is            => 'ro',
@@ -347,10 +347,6 @@ MooseX::Method::Signatures - Method declarations with type constraints and no so
 
     $foo->greet;                                    # Will fail.
 
-=head1 DISCLAIMER
-
-This is B<ALPHA SOFTWARE>. Use at your own risk. Features may change.
-
 =head1 DESCRIPTION
 
 Provides a proper method keyword, like "sub" but specifically for making methods
@@ -428,6 +424,10 @@ extra lexical variable to be created.
 
 =head1 BUGS, CAVEATS AND NOTES
 
+This module is as stable now, but this is not to say that it is entirely bug
+free. If you notice any odd behaviour (messages not being as good as they could
+for example) then please raise a bug.
+
 =head2 Fancy signatures
 
 L<Parse::Method::Signatures> is used to parse the signatures. However, some
@@ -561,6 +561,8 @@ method/subroutine within a role.
 
 =head1 SEE ALSO
 
+L<MooseX::Declare>
+
 L<Method::Signatures::Simple>
 
 L<Method::Signatures>
